@@ -14,6 +14,7 @@ my %opt = (
     scale  => 'major',
     octave => 4,
     bpm    => 80,
+    factor => 7, # for volume changes
 );
 GetOptions(\%opt,
     'tonic=s',
@@ -31,13 +32,15 @@ my $d = Music::Dice->new(
     scale_name => $opt{scale},
 );
  
-my $factor   = 7; # for volume changes
 my $c_phrase = $d->rhythmic_phrase->roll; # harmony
+# print "H: @{ $c_phrase }\n";
 my $m_phrase = $d->rhythmic_phrase->roll; # melody
+# print "M: @{ $m_phrase }\n";
 my $tonic    = $d->note->roll;
 my $mode     = $d->mode->roll;
 my @scale    = get_scale_notes($tonic, $mode);
 print "$tonic $mode: @scale\n";
+print "degree => chord | duruation\n";
 
 $d = Music::Dice->new(
     scale_note => $tonic,
@@ -54,13 +57,13 @@ $score->write_score("$0.mid");
 sub harmony {
     set_chan_patch($score, 0, 4);
     my $volume = $score->Volume;
-    $score->Volume($volume - $factor);
+    $score->Volume($volume - $opt{factor});
     for my $i (0 .. $#$c_phrase) {
         my ($degree, $triad) = $d->mode_degree_triad_roll($mode);
         my $index = $degree - 1;
         my $type = $triad eq 'diminished' ? 'dim' : $triad eq 'minor' ? 'm' : '';
         my $chord = "$scale[$index]$type";
-        print "Degree: $degree => $chord | $c_phrase->[$i]\n";
+        print "$degree => $chord | $c_phrase->[$i]\n";
         my @tones = $cn->chord_with_octave($chord, $opt{octave});
         $score->n($c_phrase->[$i], midi_format(@tones));
     }
@@ -78,7 +81,7 @@ sub melody {
 sub bass {
     set_chan_patch($score, 2, 33);
     my $volume = $score->Volume;
-    $score->Volume($volume + $factor);
+    $score->Volume($volume + $opt{factor});
     my $note = $d->note->roll . ($opt{octave} - 1);
     $score->n('wn', midi_format($note));
     $score->Volume($volume);
