@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Define and roll musical dice
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use Moo;
 use strictures 2;
@@ -307,13 +307,6 @@ has rhythmic_phrase_constraints => (
 );
 
 
-has chord_voices_nums => (
-    is      => 'ro',
-    isa     => ArrayRef[Int],
-    default => sub { [ 3, 4 ] },
-);
-
-
 has mdp => (
     is => 'lazy',
 );
@@ -650,27 +643,6 @@ sub rhythmic_phrase_constrained {
     return Games::Dice::Advanced->new($d);
 }
 
-## GAMEPLAY ##
-
-
-sub chord_voices_num {
-    my ($self) = @_;
-    my $d = sub {
-        return choose_weighted($self->chord_voices_nums, [ (1) x @{ $self->chord_voices_nums } ])
-    };
-    return Games::Dice::Advanced->new($d);
-}
-
-
-sub remove_chord_num {
-    my ($self) = @_;
-    my $d = sub {
-        my $choices = [ 0 .. $self->chord_voices_nums->[0] - 1 ];
-        return choose_weighted($choices, [ (1) x @$choices ])
-    };
-    return Games::Dice::Advanced->new($d);
-}
-
 ## UTILITY ##
 
 
@@ -698,7 +670,7 @@ Music::Dice - Define and roll musical dice
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -735,9 +707,6 @@ version 0.0104
   $roll = $d->rhythm->roll;
   $roll = $d->rhythmic_phrase->roll;
   $roll = $d->rhythmic_phrase_constrained->roll;
-  # gameplay
-  $roll = $d->chord_voices_num->roll;
-  $roll = $d->remove_chord_num->roll;
 
   # for example:
   my $phrase = $d->rhythmic_phrase->roll;
@@ -1076,14 +1045,6 @@ The number of rhythmic values in a phrase, given as an array reference.
 
 Default: C<[3,4,5]>
 
-=head2 chord_voices_nums
-
-  $chord_voices = $d->chord_voices_nums;
-
-The number of voices in a chord, given as an array reference.
-
-Default: C<[3,4]>
-
 =head2 mdp
 
   $mdp = $d->mdp;
@@ -1115,7 +1076,6 @@ The L<Music::Duration::Partition> object.
     modes                       => \@modes,
     tonnetzen                   => \@tonnetzen,
     tonnetzen_7                 => \@tonnetzen_7,
-    chord_voices_nums           => \@voices,
     rhythmic_phrase_constraints => \@constraints,
   );
 
@@ -1322,19 +1282,6 @@ Return a rhythmic phrase, given the number of B<beats>.
 Return a constrained rhythmic phrase, given the
 B<rhythmic_phrase_constraints> (number of rhythmic values).
 
-=head2 chord_voices_num
-
-  $result = $d->chord_voices_num->roll;
-
-Return one of the B<chord_voices_num> with equal probability.
-
-=head2 remove_chord_num
-
-  $result = $d->remove_chord_num->roll;
-
-Return a value between C<0> and one less than the first
-B<chord_voices_num> entry.
-
 =head2 unique_item
 
   $item = $mb->unique_item(\@excludes);
